import os
import statsbomb as sb


def test_parser():
    matches = sb.Matches(os.path.join(os.path.dirname(__file__), 'test_data', '49.json'))

    assert str(matches) == 'Matches data for ID: 49'
    assert matches.id == '49'
    assert len(matches) == 12
    assert matches.get_dataframe().to_dict(orient='records') == [
        {'away_score': 1, 'away_team': 761, 'competition': 49, 'data_version': '1.0.2', 'home_score': 1,
         'home_team': 766, 'kick_off': None, 'last_updated': '2018-09-08T07:33:39.356340', 'match_date': '2018-05-06',
         'match_id': 7444, 'match_status': 'available', 'referee_name': 'M. Vega', 'season': 3,
         'stadium_name': "Sahlen's Stadium at WakeMed Soccer Park"},
        {'away_score': 4, 'away_team': 766, 'competition': 49, 'data_version': '1.0.2', 'home_score': 1,
         'home_team': 765, 'kick_off': None, 'last_updated': '2018-09-08T07:33:39.356340', 'match_date': '2018-05-31',
         'match_id': 7519, 'match_status': 'available', 'referee_name': 'Joe Dickerson', 'season': 3,
         'stadium_name': 'Providence Park'},
        {'away_score': 2, 'away_team': 766, 'competition': 49, 'data_version': '1.0.2', 'home_score': 1,
         'home_team': 763, 'kick_off': None, 'last_updated': '2018-09-08T07:33:39.356340', 'match_date': '2018-05-20',
         'match_id': 7456, 'match_status': 'available', 'referee_name': 'D. Chesky', 'season': 3,
         'stadium_name': 'Yurcak Field'},
        {'away_score': 4, 'away_team': 766, 'competition': 49, 'data_version': '1.0.2', 'home_score': 3,
         'home_team': 764, 'kick_off': None, 'last_updated': '2018-09-08T07:33:39.356340', 'match_date': '2018-05-24',
         'match_id': 7457, 'match_status': 'available', 'referee_name': 'C. Unkel', 'season': 3,
         'stadium_name': 'Orlando City Stadium'},
        {'away_score': 0, 'away_team': 759, 'competition': 49, 'data_version': '1.0.2', 'home_score': 2,
         'home_team': 766, 'kick_off': None, 'last_updated': '2018-09-08T07:33:39.356340', 'match_date': '2018-07-12',
         'match_id': 7482, 'match_status': 'available', 'referee_name': 'D. Gutierrez', 'season': 3,
         'stadium_name': "Sahlen's Stadium at WakeMed Soccer Park"},
        {'away_score': 0, 'away_team': 766, 'competition': 49, 'data_version': '1.0.2', 'home_score': 0,
         'home_team': 767, 'kick_off': None, 'last_updated': '2018-09-08T07:33:39.356340', 'match_date': '2018-07-21',
         'match_id': 7487, 'match_status': 'available', 'referee_name': 'C. Unkel', 'season': 3,
         'stadium_name': 'Rio Tinto Stadium'},
        {'away_score': 2, 'away_team': 764, 'competition': 49, 'data_version': '1.0.2', 'home_score': 1,
         'home_team': 767, 'kick_off': None, 'last_updated': '2018-09-08T07:33:39.356340', 'match_date': '2018-07-14',
         'match_id': 7483, 'match_status': 'available', 'referee_name': 'R. Fonseca', 'season': 3,
         'stadium_name': 'Rio Tinto Stadium'},
        {'away_score': 1, 'away_team': 762, 'competition': 49, 'data_version': '1.0.2', 'home_score': 3,
         'home_team': 765, 'kick_off': None, 'last_updated': '2018-09-08T07:33:39.356340', 'match_date': '2018-07-16',
         'match_id': 7486, 'match_status': 'available', 'referee_name': 'E. Tattersall', 'season': 3,
         'stadium_name': 'Providence Park'},
        {'away_score': 4, 'away_team': 766, 'competition': 49, 'data_version': '1.0.2', 'home_score': 0,
         'home_team': 763, 'kick_off': None, 'last_updated': '2018-09-08T07:33:39.356340', 'match_date': '2018-07-15',
         'match_id': 7484, 'match_status': 'available', 'referee_name': 'D. Chesky', 'season': 3,
         'stadium_name': 'Yurcak Field'},
        {'away_score': 1, 'away_team': 763, 'competition': 49, 'data_version': '1.0.2', 'home_score': 3,
         'home_team': 767, 'kick_off': None, 'last_updated': '2018-09-08T07:33:39.356340', 'match_date': '2018-07-01',
         'match_id': 7473, 'match_status': 'available', 'referee_name': 'V. Rivas', 'season': 3,
         'stadium_name': 'Rio Tinto Stadium'},
        {'away_score': 1, 'away_team': 759, 'competition': 49, 'data_version': '1.0.2', 'home_score': 2,
         'home_team': 764, 'kick_off': None, 'last_updated': '2018-09-08T07:33:39.356340', 'match_date': '2018-07-08',
         'match_id': 7479, 'match_status': 'available', 'referee_name': 'D. Chesky', 'season': 3,
         'stadium_name': 'Orlando City Stadium'},
        {'away_score': 0, 'away_team': 760, 'competition': 49, 'data_version': '1.0.2', 'home_score': 1,
         'home_team': 761, 'kick_off': None, 'last_updated': '2018-09-08T07:33:39.356340', 'match_date': '2018-07-15',
         'match_id': 7485, 'match_status': 'available', 'referee_name': 'N. Simon', 'season': 3,
         'stadium_name': 'Toyota Park'}
    ]



from statsbomb.utils import get_event_name


def test_get_event_name():
    assert get_event_name({'name': 'value'}) == 'value'
    assert get_event_name({'name': 1}) == 1
    assert get_event_name({'name': 'value', 'other_key': 'value2'}) == 'value'
    assert get_event_name({'other': 'value'}) is None
    assert get_event_name({}) is None



import os
import statsbomb as sb


def test_parser():
    comps = sb.Competitions(os.path.join(os.path.dirname(__file__), 'test_data', 'competitions.json'))

    assert str(comps) == 'Competitions data for ID: competitions'
    assert comps.id == 'competitions'
    assert len(comps) == 3
    assert comps.get_dataframe().to_dict(orient='records') == [
        {'competition_id': 37, 'competition_name': "FA Women's Super League", 'country_name': 'England',
         'match_available': '2018-09-08T07:33:39.356340', 'match_updated': '2018-09-08T07:33:39.356340',
         'season_id': 1, 'season_name': '2017/2018'},
        {'competition_id': 43, 'competition_name': 'FIFA World Cup', 'country_name': 'International',
         'match_available': '2018-09-08T07:33:39.356340', 'match_updated': '2018-09-08T14:30:04.356514',
         'season_id': 3, 'season_name': '2018'},
        {'competition_id': 49, 'competition_name': 'NWSL', 'country_name': 'United States of America',
         'match_available': '2018-09-08T07:33:39.356340', 'match_updated': '2018-09-08T07:33:39.356340',
         'season_id': 3, 'season_name': '2018'}
    ]



import os
import pytest
import statsbomb as sb


@pytest.fixture(scope='module')
def events_json():
    return sb.Events(os.path.join(os.path.dirname(__file__), 'test_data', '8656.json'))


def test_class():
    events = events_json()
    assert str(events) == 'Events data for ID: 8656'
    assert events.id == '8656'
    assert len(events) == 16

    with pytest.raises(AssertionError):
        events.get_dataframe('fake_event')

    with pytest.raises(AssertionError):
        events.get_dataframe('block')


def test_shots():
    events = events_json()
    assert events.get_dataframe('shot').to_dict(orient='records') == [
        {'event_type': 'shot', 'id': '0160a53e-9ed5-48ff-adfe-be306d551b4a', 'index': 95, 'period': 1,
         'timestamp': '00:04:46.900', 'minute': 4, 'second': 46, 'possession': 10, 'possession_team': 'England',
         'play_pattern': 'From Free Kick', 'off_camera': False, 'team': 'England', 'player': 'Kieran Trippier',
         'position': 'Right Wing Back', 'duration': 1.013, 'under_pressure': None, 'statsbomb_xg': 0.08887702,
         'key_pass_id': None, 'body_part': 'Right Foot', 'type': 'Free Kick', 'outcome': 'Goal', 'technique': 'Normal',
         'first_time': None, 'follows_dribble': None, 'redirect': None, 'one_on_one': None, 'open_goal': None,
         'deflected': None, 'start_location_x': 96.0, 'start_location_y': 43.0, 'end_location_x': 120.0,
         'end_location_y': 43.1, 'end_location_z': 2.1},
        {'event_type': 'shot', 'id': '48e28801-8408-4b74-806a-5f1e40224cce', 'index': 307, 'period': 1,
         'timestamp': '00:13:41.780', 'minute': 13, 'second': 41, 'possession': 27, 'possession_team': 'England',
         'play_pattern': 'From Corner', 'off_camera': False, 'team': 'England', 'player': 'Harry Maguire',
         'position': 'Left Center Back', 'duration': 1.453, 'under_pressure': None, 'statsbomb_xg': 0.013174075,
         'key_pass_id': 'd492f17b-6dd5-45d1-aa51-ce32436a57a3', 'body_part': 'Head', 'type': 'Open Play',
         'outcome': 'Off T', 'technique': 'Normal', 'first_time': None, 'follows_dribble': None, 'redirect': None,
         'one_on_one': None, 'open_goal': None, 'deflected': None, 'start_location_x': 111.0, 'start_location_y': 37.0,
         'end_location_x': 120.0, 'end_location_y': 45.1, 'end_location_z': 0.3},
        {'event_type': 'shot', 'id': 'f25a693f-81cd-41ec-a57f-957da6eb7626', 'index': 436, 'period': 1,
         'timestamp': '00:18:18.313', 'minute': 18, 'second': 18, 'possession': 37, 'possession_team': 'Croatia',
         'play_pattern': 'From Throw In', 'off_camera': False, 'team': 'Croatia', 'player': 'Ivan Perisic',
         'position': 'Left Wing', 'duration': 1.067, 'under_pressure': None, 'statsbomb_xg': 0.03211567,
         'key_pass_id': 'f695d356-f55d-4eb5-9069-8a8e157eef53', 'body_part': 'Right Foot', 'type': 'Open Play',
         'outcome': 'Off T', 'technique': 'Normal', 'first_time': None, 'follows_dribble': None, 'redirect': None,
         'one_on_one': None, 'open_goal': None, 'deflected': True, 'start_location_x': 94.0, 'start_location_y': 20.0,
         'end_location_x': 120.0, 'end_location_y': 34.9, 'end_location_z': 0.5}
    ]


def test_passes():
    events = events_json()
    assert events.get_dataframe('pass').to_dict(orient='records') == [
        {'event_type': 'pass', 'id': '7e92f6b8-48e8-4616-9997-de689e48e4fd', 'index': 439, 'period': 1,
         'timestamp': '00:18:59.780', 'minute': 18, 'second': 59, 'possession': 38, 'possession_team': 'England',
         'play_pattern': 'From Throw In', 'off_camera': False, 'team': 'England', 'player': 'Ashley Young',
         'position': 'Left Wing Back', 'duration': 3.56, 'under_pressure': None, 'recipient': 'Harry Maguire',
         'length': 38.078865, 'angle': 2.7367008, 'height': 'High Pass', 'outcome': None, 'type': 'Throw-in',
         'body_part': None, 'assisted_shot_id': None, 'pass_backheel': None, 'deflected': None,
         'miscommunication': None, 'through_ball': None, 'cross': None, 'cut_back': None, 'switch': None,
         'shot_assist': None, 'goal_assist': None, 'start_location_x': 55.0, 'start_location_y': 1.0,
         'end_location_x': 20.0, 'end_location_y': 16.0},
        {'event_type': 'pass', 'id': '0a7f0193-8257-40f3-b19b-2b046c5a08bc', 'index': 450, 'period': 1,
         'timestamp': '00:19:11.860', 'minute': 19, 'second': 11, 'possession': 38, 'possession_team': 'England',
         'play_pattern': 'From Throw In', 'off_camera': False, 'team': 'England', 'player': 'Kieran Trippier',
         'position': 'Right Wing Back', 'duration': 3.973, 'under_pressure': None, 'recipient': 'Raheem Sterling',
         'length': 32.38827, 'angle': -0.15499674, 'height': 'High Pass', 'outcome': 'Incomplete', 'type': None,
         'body_part': 'Left Foot', 'assisted_shot_id': None, 'pass_backheel': None, 'deflected': None,
         'miscommunication': None, 'through_ball': None, 'cross': None, 'cut_back': None, 'switch': None,
         'shot_assist': None, 'goal_assist': None, 'start_location_x': 74.0, 'start_location_y': 78.0,
         'end_location_x': 106.0, 'end_location_y': 73.0},
        {'event_type': 'pass', 'id': '510783ec-ea0e-4674-8e78-82e2147507a2', 'index': 3057, 'period': 4,
         'timestamp': '00:03:01.550', 'minute': 108, 'second': 1, 'possession': 229, 'possession_team': 'Croatia',
         'play_pattern': 'From Throw In', 'off_camera': False, 'team': 'Croatia', 'player': 'Ivan Perisic',
         'position': 'Left Wing', 'duration': 2.08, 'under_pressure': None, 'recipient': 'Mario Mandzukic',
         'length': 15.556349, 'angle': 0.7853982, 'height': 'High Pass', 'outcome': None, 'type': 'Recovery',
         'body_part': 'Head', 'assisted_shot_id': '5a2e748a-46e8-4f7e-936a-1beae50b693d', 'pass_backheel': None,
         'deflected': None, 'miscommunication': None, 'through_ball': None, 'cross': None, 'cut_back': None,
         'switch': None, 'shot_assist': None, 'goal_assist': True, 'start_location_x': 103.0, 'start_location_y': 20.0,
         'end_location_x': 114.0, 'end_location_y': 31.0},
        {'event_type': 'pass', 'id': '7cfa57b4-9003-462a-b11a-5979f95639ac', 'index': 3170, 'period': 4,
         'timestamp': '00:10:59.150', 'minute': 115, 'second': 59, 'possession': 239, 'possession_team': 'England',
         'play_pattern': 'From Free Kick', 'off_camera': False, 'team': 'England', 'player': 'Jordan Pickford',
         'position': 'Goalkeeper', 'duration': 3.48, 'under_pressure': None, 'recipient': 'Harry Kane',
         'length': 71.063354, 'angle': -0.0422284, 'height': 'High Pass', 'outcome': 'Incomplete', 'type': 'Free Kick',
         'body_part': 'Left Foot', 'assisted_shot_id': None, 'pass_backheel': None, 'deflected': None,
         'miscommunication': None, 'through_ball': None, 'cross': None, 'cut_back': None, 'switch': None,
         'shot_assist': None, 'goal_assist': None, 'start_location_x': 14.0, 'start_location_y': 38.0,
         'end_location_x': 85.0, 'end_location_y': 35.0}
    ]


def test_ball_recovery():
    events = events_json()
    assert events.get_dataframe('ball recovery').to_dict(orient='records') == [
        {'event_type': 'ball recovery', 'id': '89300a03-5ea3-4962-96d2-ba8d613f0dae', 'index': 3208, 'period': 4,
         'timestamp': '00:13:42.563', 'minute': 118, 'second': 42, 'possession': 242, 'possession_team': 'England',
         'play_pattern': 'From Counter', 'off_camera': False, 'team': 'England', 'player': 'Harry Maguire',
         'position': 'Left Center Back', 'duration': None, 'under_pressure': None, 'offensive': None,
         'recovery_failure': None, 'start_location_x': 51.0, 'start_location_y': 8.0}
    ]


def test_ball_receipt():
    events = events_json()
    assert events.get_dataframe('ball receipt*').to_dict(orient='records') == [
        {'event_type': 'ball receipt*', 'id': 'd12476d5-363d-4779-89d7-22fe06c60610', 'index': 3211, 'period': 4,
         'timestamp': '00:13:46.563', 'minute': 118, 'second': 46, 'possession': 242, 'possession_team': 'England',
         'play_pattern': 'From Counter', 'off_camera': False, 'team': 'England', 'player': 'John Stones',
         'position': 'Right Center Back', 'duration': None, 'under_pressure': True, 'outcome': None,
         'start_location_x': 51.0, 'start_location_y': 25.0},
        {'event_type': 'ball receipt*', 'id': '3fe3b28b-70a3-4859-a4a8-a34afdc305a8', 'index': 3218, 'period': 4,
         'timestamp': '00:13:57.430', 'minute': 118, 'second': 57, 'possession': 242, 'possession_team': 'England',
         'play_pattern': 'From Counter', 'off_camera': False, 'team': 'England', 'player': 'Jamie Vardy',
         'position': 'Left Center Forward', 'duration': None, 'under_pressure': None, 'outcome': None,
         'start_location_x': 96.0, 'start_location_y': 60.0}
    ]


def test_substitution():
    events = events_json()
    assert events.get_dataframe('substitution').to_dict(orient='records') == [
        {'event_type': 'substitution', 'id': '59dfc811-3891-4316-a299-59cafe91a99d', 'index': 1949, 'period': 2,
         'timestamp': '00:28:10.693', 'minute': 73, 'second': 10, 'possession': 151, 'possession_team': 'Croatia',
         'play_pattern': 'From Corner', 'off_camera': False, 'team': 'England', 'player': 'Raheem Sterling',
         'position': 'Left Center Forward', 'duration': None, 'under_pressure': None,
         'replacement': {'id': 3318, 'name': 'Marcus Rashford'}, 'outcome': 'Tactical'}
    ]



import json


class BaseParser:
    """
    Base class for parsers.
    """
    def __init__(self, file_path: str):
        self.file_path = file_path
        self.data = json.load(open(self.file_path))
        self.id = self.file_path.split('/')[-1].split('.json')[0]

    def __repr__(self):
        return '{} data for ID: {}'.format(self.__class__.__name__, self.id)

    def __str__(self):
        return self.__repr__()

    def __len__(self):
        return len(self.data)



import os
import statsbomb as sb


def test_parser():
    lineup = sb.Lineups(os.path.join(os.path.dirname(__file__), 'test_data', '7457.json'))

    assert str(lineup) == 'Lineups data for ID: 7457'
    assert lineup.id == '7457'
    assert len(lineup) == 2
    assert lineup.get_dataframe().to_dict(orient='records') == [
        {'country': 'United States of America', 'jersey_number': 14, 'player_id': 5034,
         'player_name': 'Jessica McDonald', 'team_id': 766, 'team_name': 'North Carolina Courage'},
        {'country': 'New Zealand', 'jersey_number': 6, 'player_id': 5037, 'player_name': 'Abby Erceg', 'team_id': 766,
         'team_name': 'North Carolina Courage'},
        {'country': 'Brazil', 'jersey_number': 10, 'player_id': 5044,
         'player_name': 'Debora Cristiane de Oliveira', 'team_id': 766, 'team_name': 'North Carolina Courage'},
        {'country': 'United States of America', 'jersey_number': 15, 'player_id': 5047,
         'player_name': 'Jaelene Hinkle', 'team_id': 766, 'team_name': 'North Carolina Courage'},
        {'country': 'United States of America', 'jersey_number': 0, 'player_id': 5048,
         'player_name': 'Katelyn Rowland', 'team_id': 766, 'team_name': 'North Carolina Courage'},
        {'country': 'United States of America', 'jersey_number': 25, 'player_id': 5050,
         'player_name': 'Meredith Speck', 'team_id': 766, 'team_name': 'North Carolina Courage'},
        {'country': 'United States of America', 'jersey_number': 23, 'player_id': 5080,
         'player_name': 'Kristen Hamilton', 'team_id': 766, 'team_name': 'North Carolina Courage'},
        {'country': 'United States of America', 'jersey_number': 13, 'player_id': 5081,
         'player_name': 'Abby Dahlkemper', 'team_id': 766, 'team_name': 'North Carolina Courage'},
        {'country': 'United States of America', 'jersey_number': 11, 'player_id': 5083,
         'player_name': 'Merritt Mathias', 'team_id': 766, 'team_name': 'North Carolina Courage'},
        {'country': 'Ireland', 'jersey_number': 8, 'player_id': 5084, 'player_name': "Denise O'Sullivan",
         'team_id': 766, 'team_name': 'North Carolina Courage'},
        {'country': 'United States of America', 'jersey_number': 5, 'player_id': 5087, 'player_name': 'Samantha Mewis',
         'team_id': 766, 'team_name': 'North Carolina Courage'},
        {'country': 'United States of America', 'jersey_number': 19, 'player_id': 5088,
         'player_name': 'Crystal Alyssia Dunn', 'team_id': 766, 'team_name': 'North Carolina Courage'},
        {'country': 'United States of America', 'jersey_number': 7, 'player_id': 5091, 'player_name': 'McCall Zerboni',
         'team_id': 766, 'team_name': 'North Carolina Courage'},
        {'country': 'Brazil', 'jersey_number': 19, 'player_id': 5060, 'player_name': 'Poliana Barbosa Medeiros',
         'team_id': 764, 'team_name': 'Orlando Pride'},
        {'country': 'United States of America', 'jersey_number': 17, 'player_id': 5062,
         'player_name': 'Dani Weatherholt', 'team_id': 764, 'team_name': 'Orlando Pride'},
        {'country': 'United States of America', 'jersey_number': 6, 'player_id': 5063, 'player_name': 'Chioma Ubogagu',
         'team_id': 764, 'team_name': 'Orlando Pride'},
        {'country': 'United States of America', 'jersey_number': 16, 'player_id': 5064,
         'player_name': 'Carson Pickett', 'team_id': 764, 'team_name': 'Orlando Pride'},
        {'country': 'United States of America', 'jersey_number': 12, 'player_id': 5068,
         'player_name': 'Kristen Edmonds', 'team_id': 764, 'team_name': 'Orlando Pride'},
        {'country': 'United States of America', 'jersey_number': 7, 'player_id': 5070,
         'player_name': 'Christine Nairn', 'team_id': 764, 'team_name': 'Orlando Pride'},
        {'country': 'Canada', 'jersey_number': 4, 'player_id': 5074, 'player_name': 'Shelina Zadorsky', 'team_id': 764,
         'team_name': 'Orlando Pride'},
        {'country': 'Australia', 'jersey_number': 5, 'player_id': 5076, 'player_name': 'Emily van Egmond',
         'team_id': 764, 'team_name': 'Orlando Pride'},
        {'country': 'Australia', 'jersey_number': 14, 'player_id': 5078, 'player_name': 'Alanna Kennedy',
         'team_id': 764, 'team_name': 'Orlando Pride'},
        {'country': 'Brazil', 'jersey_number': 10, 'player_id': 5082, 'player_name': 'Marta Vieira da Silva',
         'team_id': 764, 'team_name': 'Orlando Pride'},
        {'country': 'United States of America', 'jersey_number': 13, 'player_id': 5085, 'player_name': 'Alex Morgan',
         'team_id': 764, 'team_name': 'Orlando Pride'},
        {'country': 'United States of America', 'jersey_number': 15, 'player_id': 5086, 'player_name': 'Rachel Hill',
         'team_id': 764, 'team_name': 'Orlando Pride'},
        {'country': 'United States of America', 'jersey_number': 11, 'player_id': 5089, 'player_name': 'Ali Krieger',
         'team_id': 764, 'team_name': 'Orlando Pride'},
        {'country': 'United States of America', 'jersey_number': 24, 'player_id': 5090, 'player_name': 'Ashlyn Harris',
         'team_id': 764, 'team_name': 'Orlando Pride'}
    ]
